## Summary of bug
...

## Environment information
- Platform: ...
- *Python* version: ...
- `explabox` version: ...

## Reproducing the bug
Steps to reproduce the behavior:

```python
from explabox import Explabox
...
```

## Expected behavior
...
